==> copyartifact-1.5-sources.jar: hudson/plugins/copyartifact/StatusBuildSelector.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2004-2010, Sun Microsystems, Inc., Alan Harder
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package hudson.plugins.copyartifact;

import hudson.Extension;
import hudson.model.Descriptor;
import hudson.model.Job;
import hudson.model.Run;
import org.kohsuke.stapler.DataBoundConstructor;

/**
 * Copy artifacts from the latest successful or stable build.
 * @author Alan.Harder@sun.com
 */
public class StatusBuildSelector extends BuildSelector {
    private Boolean stable;

    @DataBoundConstructor
    public StatusBuildSelector(boolean stableOnly) {
        this.stable = stableOnly ? Boolean.TRUE : null;
    }

    public boolean isStable() {
        return stable != null && stable.booleanValue();
    }

    @Override
    public Run<?,?> getBuild(Job<?,?> job) {
        return isStable() ? job.getLastStableBuild() : job.getLastSuccessfulBuild();
    }

    @Extension(ordinal=100)
    public static final Descriptor<BuildSelector> DESCRIPTOR =
            new SimpleBuildSelectorDescriptor(
                StatusBuildSelector.class, Messages._StatusBuildSelector_DisplayName());
}

==> copyartifact-1.7-sources.jar: hudson/plugins/copyartifact/StatusBuildSelector.java <==
/*
 * The MIT License
 *
 * Copyright (c) 2004-2010, Sun Microsystems, Inc., Alan Harder
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package hudson.plugins.copyartifact;

import hudson.EnvVars;
import hudson.Extension;
import hudson.model.Descriptor;
import hudson.model.Job;
import hudson.model.Run;
import org.kohsuke.stapler.DataBoundConstructor;

/**
 * Copy artifacts from the latest successful or stable build.
 * @author Alan.Harder@sun.com
 */
public class StatusBuildSelector extends BuildSelector {
    private Boolean stable;

    @DataBoundConstructor
    public StatusBuildSelector(boolean stableOnly) {
        this.stable = stableOnly ? Boolean.TRUE : null;
    }

    public boolean isStable() {
        return stable != null && stable.booleanValue();
    }

    @Override
    public Run<?,?> getBuild(Job<?,?> job, EnvVars env) {
        return isStable() ? job.getLastStableBuild() : job.getLastSuccessfulBuild();
    }

    @Extension(ordinal=100)
    public static final Descriptor<BuildSelector> DESCRIPTOR =
            new SimpleBuildSelectorDescriptor(
                StatusBuildSelector.class, Messages._StatusBuildSelector_DisplayName());
}
